#!/bin/sh -eu

#
# This script installs the provided debs and runs the provided autopilot test suite.
# It is based off the example scripts that come with Otto

# Copyright © 2013 Canonical Ltd.
# Author: Jean-baptiste Lallement <jean-baptiste.lallement@canonical.com>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
exec 2>&1

USER=ubuntu
TESTBASE=/var/local/autopilot/
AP_ARTIFACTS=$TESTBASE/artifacts/
AP_RESULTS=$TESTBASE/results/
AP_TESTSUITES=$TESTBASE/testsuites
AP_LOGFILE=$TESTBASE/autopilot.log
AP_OPTS="-v -r -rd $AP_ARTIFACTS -f xml"

DEB_SOURCE_DIR=/var/local/autopilot-install-local/debs

install_debs() {
	if [ -e ${DEB_SOURCE_DIR} ]; then
		# Taken from generic-medium-tests, using apt-get resolves any
		# dependencies.
		package_list=""
		for i in `ls ${DEB_SOURCE_DIR}/*.deb`; do
		  package_name=`dpkg -I $i | grep Package | cut -d " " -f 3`
		  package_list="$package_list $package_name"
		done
		sudo apt-get -y --force-yes install $package_list
	else
		echo "I: No extra debs to install"
	fi
}

setup_tests() {
	# Only required while we're using unity as a desktop
    # Disable notifications and screensaver
    gsettings set com.ubuntu.update-notifier show-apport-crashes false
    gsettings set org.gnome.desktop.screensaver idle-activation-enabled false

	# Workaround for autopilot crashing when parsing debug output
	export LANG=C

	# Autopilot needs write access on /dev/uinput to create
	# /dev/autoilot-uinput. To prevent that file from being read-only after a
	# reboot, make both of them writeable
	sudo chmod 666 /dev/autopilot-uinput || true
	sudo chmod 666 /dev/uinput || true

    sudo mkdir -p $AP_ARTIFACTS $AP_RESULTS
    sudo chown $USER:$USER $TESTBASE $AP_ARTIFACTS $AP_RESULTS
}

# Similar to what happens in the current generic-mediumtests for logging.
log_details() {
    echo "Logging running details"
    apt-cache policy libautopilot-qt python-autopilot libxpathselect1.3
    xrandr
}

# Expects each test suite per line in the file.
run_tests() {
    if [ ! -e $AP_TESTSUITES ]; then
        echo "E: '$AP_TESTSUITES does not exist. Exiting!"
        exit 1
    fi

	while read suite; do
		echo "I: Running ${suite}"
        set +e
        autopilot run $suite $AP_OPTS -o $AP_RESULTS/$suite.xml 2>&1|tee $AP_LOGFILE
        AP_RC=$?
        set -e
	done < $AP_TESTSUITES

	echo "I: No test left to run"
	sudo shutdown -h +1
}

install_debs
setup_tests
log_details
run_tests
